<?php

namespace Drupal\box\Entity;

use Drupal\box\BoxAccessControlHandler;
use Drupal\box\BoxListBuilder;
use Drupal\box\BioxStorage;
use Drupal\box\BoxStorageSchema;
use Drupal\box\BoxTranslationHandler;
use Drupal\box\BoxViewBuilder;
use Drupal\box\BioxViewsData;
use Drupal\box\Form\BoxDeleteForm;
use Drupal\box\Form\BoxDeleteMultiple;
use Drupal\box\Form\BoxForm;
use Drupal\box\Routing\BoxRouteProvider;
use Drupal\Core\Entity\Attribute\ContentEntityType;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Field\BaseFieldDefinition;
use Drupal\Core\StringTranslation\TranslatableMarkup;

/**
 * Defines the Biox entity.
 *
 * @ingroup biox
 */
#[ContentEntityType(
  id: 'biox',
  label: new TranslatableMarkup('Biox'),
  label_collection: new TranslatableMarkup('Bioxes'),
  label_singular: new TranslatableMarkup('biox'),
  label_plural: new TranslatableMarkup('bioxes'),
  entity_keys: [
    'id' => 'id',
    'revision' => 'vid',
    'bundle' => 'bundle',
    'label' => 'label',
    'langcode' => 'langcode',
    'uuid' => 'uuid',
    'uid' => 'uid',
    'owner' => 'uid',
    'published' => 'status',
    'status' => 'status',
  ],
  handlers: [
    'storage' => BioxStorage::class,
    'storage_schema' => BoxStorageSchema::class,
    'access' => BoxAccessControlHandler::class,
    'view_builder' => BoxViewBuilder::class,
    'views_data' => BioxViewsData::class,
    'form' => [
      'default' => BoxForm::class,
      'add' => BoxForm::class,
      'edit' => BoxForm::class,
      'delete' => BoxDeleteForm::class,
      'delete-multiple-confirm' => BoxDeleteMultiple::class,
    ],
    'route_provider' => [
      'html' => BoxRouteProvider::class,
    ],
    'list_builder' => BoxListBuilder::class,
    'translation' => BoxTranslationHandler::class,
  ],
  links: [
    'canonical' => '/biox/{biox}',
    'add-page' => '/biox/add',
    'add-form' => '/biox/add/{biox_type}',
    'edit-form' => '/biox/{biox}/edit',
    'delete-form' => '/biox/{biox}/delete',
    'delete-multiple-form' => '/admin/content/biox/delete',
    'version-history' => '/biox/{biox}/revisions',
    'revision' => '/biox/{biox}/revisions/{biox_revision}/view',
    'revision-delete' => '/biox/{biox}/revisions/{biox_revision}/delete',
    'revision-revert' => '/biox/{biox}/revisions/{biox_revision}/revert',
    'translation-revert' => '/biox/{biox}/revisions/{biox_revision}/revert/{langcode}',
    'collection' => '/admin/content/biox',
  ],
  admin_permission: 'administer biox entities',
  permission_granularity: 'bundle',
  bundle_entity_type: 'biox_type',
  bundle_label: new TranslatableMarkup('Biox type'),
  base_table: 'biox',
  data_table: 'biox_field_data',
  revision_table: 'biox_revision',
  revision_data_table: 'biox_field_revision',
  translatable: TRUE,
  show_revision_ui: TRUE,
  label_count: [
    'singular' => '@count biox',
    'plural' => '@count bioxes',
  ],
  field_ui_base_route: 'entity.biox_type.edit_form',
  common_reference_target: TRUE,
  revision_metadata_keys: [
    'revision_user' => 'revision_uid',
    'revision_created' => 'revision_timestamp',
    'revision_log_message' => 'revision_log',
  ]
)]
class Biox extends Box implements BoxInterface {

  /**
   * {@inheritdoc}
   */
  public static function baseFieldDefinitions(EntityTypeInterface $entity_type): array {
    $fields = parent::baseFieldDefinitions($entity_type);

    // Set ID back to integer.
    $fields['id'] = BaseFieldDefinition::create('integer')
      ->setLabel(new TranslatableMarkup('ID'))
      ->setReadOnly(TRUE)
      ->setSetting('unsigned', TRUE);

    return $fields;
  }

  /**
   * {@inheritdoc}
   */
  public function bundleLabel(): ?string {
    $bundle = BioxType::load($this->bundle());
    return $bundle?->label();
  }

}
