<?php

namespace Drupal\box\Entity;

use Drupal\box\BoxTypeListBuilder;
use Drupal\box\Form\BoxTypeDeleteForm;
use Drupal\box\Form\BoxTypeForm;
use Drupal\Core\Entity\Attribute\ConfigEntityType;
use Drupal\Core\Entity\Routing\AdminHtmlRouteProvider;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\user\Entity\EntityPermissionsRouteProvider;

/**
 * Defines the Biox bundle entity.
 */
#[ConfigEntityType(
  id: 'biox_type',
  label: new TranslatableMarkup('Biox type'),
  label_collection: new TranslatableMarkup('Biox types'),
  label_singular: new TranslatableMarkup('biox type'),
  label_plural: new TranslatableMarkup('biox types'),
  config_prefix: 'biox_type',
  entity_keys: [
    'id' => 'id',
    'label' => 'label',
  ],
  handlers: [
    'list_builder' => BoxTypeListBuilder::class,
    'form' => [
      'add' => BoxTypeForm::class,
      'edit' => BoxTypeForm::class,
      'delete' => BoxTypeDeleteForm::class,
    ],
    'route_provider' => [
      'html' => AdminHtmlRouteProvider::class,
      'permissions' => EntityPermissionsRouteProvider::class,
    ],
  ],
  links: [
    'add-form' => '/admin/structure/biox-types/add',
    'edit-form' => '/admin/structure/biox-types/manage/{biox_type}',
    'delete-form' => '/admin/structure/biox-types/manage/{biox_type}/delete',
    'entity-permissions-form' => '/admin/structure/biox-types/manage/{biox_type}/permissions',
    'collection' => '/admin/structure/biox-types',
  ],
  admin_permission: 'administer biox types',
  bundle_of: 'biox',
  label_count: [
    'singular' => '@count biox type',
    'plural' => '@count biox types',
  ],
  config_export: [
    'label',
    'id',
    'description',
    'new_revision',
    'require_revision_log',
  ])]
class BioxType extends BoxType implements BoxTypeInterface {

}
